import * as z from "zod/v4";

const rangePattern = /^\d{1,3}–\d{1,3}$/;

const optionField = z.object({
  optionId: z.string(),
  price: z.number().optional(),
  pricePercent: z.number().optional(),
  priceRange: z.string().regex(rangePattern, "Format must be like '10–80'").optional(),
});

const extraField = z.object({
  extraId: z.string(),
  price: z.number().optional(),
  pricePercent: z.number().optional(),
  priceRange: z.string().regex(rangePattern, "Format must be like '10–80'").optional(),
});

export const commissionTypeSchema = z.object({
  name: z.string().min(1, "Name is required. Min 1 character."),
  description: z.string().optional(),
  options: z.array(optionField).optional(),
  extras: z.array(extraField).optional(),
})

export type commissionTypeSchema = z.infer<typeof commissionTypeSchema>